import express, {type Router} from "express";
import AdminGuard from "@validators/AdminGuard";
import UserGuard from "@validators/UserGuard";
import CategoryController from "@controllers/category.controller";


const CatalogRouter: Router = express.Router();

//-- MODELS >>

CatalogRouter.route('/model/new').get(AdminGuard)

CatalogRouter.route('/model/all').get()

CatalogRouter.route('/model/:modelSlug')
	.get(UserGuard)
	.patch(AdminGuard)
	.delete(AdminGuard)


//-- CATEGORY >>

CatalogRouter.route('/category/new').get(AdminGuard, CategoryController.create)

CatalogRouter.route('/category/all').get(CategoryController.getAll)

CatalogRouter.route('/category/:categorySlug')
	.get(UserGuard, CategoryController.getBySlug)
	.patch(AdminGuard, CategoryController.update)
	.delete(AdminGuard, CategoryController.delete)


//-- BRAND >>

CatalogRouter.route('/brand/new').post(AdminGuard)
CatalogRouter.route('/brand/all').get()
CatalogRouter.route('/brand/:brandSlug')
	.get(UserGuard)
	.patch(AdminGuard)
	.delete(AdminGuard)

export default CatalogRouter;